@@ -1,5 +1,7 @@
 import json
-from typing import Any, Callable, Dict, List, Optional, Union, Generator
+from typing import Any, Callable, Dict, List, Optional, Union, Generator, Tuple
+
+from requests import Response
 
 from spark_pipeline_framework.utilities.api_helper.http_request import HelixHttpRequest
 from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
@@ -45,6 +47,8 @@ class HttpDataReceiver(FrameworkTransformer):
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
         log_response: bool = False,
+        error_view: Optional[str] = None,
+        raise_error: bool = True,
     ) -> None:
         """
         Transformer to call and receive data from an API
@@ -57,6 +61,8 @@ class HttpDataReceiver(FrameworkTransformer):
         :param progress_logger: progress logger
         it supposed to return a HelixHttpRequest to be used to call the API or return None to end the API call loop
         :param response_processor: it can change the result before loading to spark df
+        :param error_view: (Optional) log the details of the api failure into `error_view` view.
+        :param raise_error: (Optional) Raise error in case of api failure
         """
         super().__init__(
             name=name, parameters=parameters, progress_logger=progress_logger
@@ -83,16 +89,23 @@ class HttpDataReceiver(FrameworkTransformer):
                 Callable[
                     [
                         List[Dict[str, Any]],
-                        Dict[str, Any],
+                        List[Dict[str, Any]],
+                        Response,
                         HelixHttpRequest,
                         Optional[ProgressLogger],
                     ],
-                    List[Dict[str, Any]],
+                    Tuple[List[Dict[str, Any]], List[Dict[str, Any]]],
                 ]
             ]
         ] = Param(self, "response_processor", "")
         self._setDefault(response_processor=None)
 
+        self.error_view: Param[Optional[str]] = Param(self, "error_view", "")
+        self._setDefault(error_view=None)
+
+        self.raise_error: Param[bool] = Param(self, "raise_error", "")
+        self._setDefault(raise_error=raise_error)
+
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
@@ -101,6 +114,8 @@ class HttpDataReceiver(FrameworkTransformer):
             [DataFrame, Optional[ProgressLogger]],
             Generator[HelixHttpRequest, None, None],
         ] = self.getHttpRequestGenerator()
+        raise_error: bool = self.getRaiseError()
+        error_view: Optional[str] = self.getOrDefault(self.error_view)
         view_name = self.getView()
         name: Optional[str] = self.getName()
 
@@ -109,43 +124,72 @@ class HttpDataReceiver(FrameworkTransformer):
         with ProgressLogMetric(
             name=f"{name}_http_data_receiver", progress_logger=progress_logger
         ):
-            responses: List[Dict[str, Any]] = []
+            success_responses: List[Dict[str, Any]] = []
+            error_responses: List[Dict[str, Any]] = []
             try:
                 for http_request in http_request_generator(df, progress_logger):
+                    # Added the statement so the error is not immediately raised
+                    http_request.set_raise_error(raise_error)
                     self.logger.debug(f"Calling API: {http_request.to_string()}...")
                     if progress_logger:
                         progress_logger.write_to_log(
                             f"Calling API: {http_request.to_string()}..."
                         )
-                    response = http_request.get_result()
+                    response = http_request.get_response()
 
                     self.logger.info(
-                        f"Successfully retrieved: {http_request.url} with status {response.status}"
+                        f"Api processed: {http_request.url} with status {response.status_code}"
                     )
                     if self.getLogResponse():
-                        self.logger.info(
-                            f"Response: {json.dumps(response.result, default=str)}"
-                        )
+                        self.logger.info(f"Response: {response.text}")
                     if progress_logger:
                         progress_logger.write_to_log(
-                            f"Successfully retrieved: {http_request.url} with status {response.status}"
+                            f"Api processed: {http_request.url} with status {response.status_code}"
                         )
                         if self.getLogResponse():
                             progress_logger.write_to_log(
-                                f"Response [{response.status}]: {json.dumps(response.result, default=str)}"
+                                f"Response [{response.status_code}]: {response.text}"
                             )
 
                     # accumulated responses before loading to spark
                     response_processor = self.getResponseProcessor()
+
                     if response_processor:
-                        responses = response_processor(
-                            responses, response.result, http_request, progress_logger
+                        success_responses, error_responses = response_processor(
+                            success_responses,
+                            error_responses,
+                            response,
+                            http_request,
+                            progress_logger,
                         )
                     else:
-                        responses.append(response.result)
+                        if response.ok:
+                            success_responses.append(response.json())
+                        else:
+                            error_responses.append(
+                                {
+                                    "request": {
+                                        "url": http_request.url,
+                                        "headers": http_request.headers,
+                                        "method": http_request.request_type,
+                                    },
+                                    "response": {
+                                        "content": response.text,
+                                        "status_code": response.status_code,
+                                        "url": response.url,
+                                        "headers": response.headers,
+                                    },
+                                }
+                            )
+
+                if error_responses and error_view:
+                    error_responses_df = df.sql_ctx.read.json(
+                        sc(df).parallelize([json.dumps(r) for r in error_responses])
+                    )
+                    error_responses_df.createOrReplaceTempView(error_view)
 
                 df2 = df.sql_ctx.read.json(
-                    sc(df).parallelize([json.dumps(r) for r in responses])
+                    sc(df).parallelize([json.dumps(r) for r in success_responses])
                 )
                 df2.createOrReplaceTempView(view_name)
             except Exception as e:
@@ -179,11 +223,12 @@ class HttpDataReceiver(FrameworkTransformer):
         Callable[
             [
                 List[Dict[str, Any]],
-                Dict[str, Any],
+                List[Dict[str, Any]],
+                Response,
                 HelixHttpRequest,
                 Optional[ProgressLogger],
             ],
-            List[Dict[str, Any]],
+            Tuple[List[Dict[str, Any]], List[Dict[str, Any]]],
         ]
     ]:
         return self.getOrDefault(self.response_processor)
@@ -191,3 +236,7 @@ class HttpDataReceiver(FrameworkTransformer):
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getLogResponse(self) -> bool:
         return self.getOrDefault(self.log_response)
+
+    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
+    def getRaiseError(self) -> bool:
+        return self.getOrDefault(self.raise_error)
