@@ -40,8 +40,8 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         self,
         # add your parameters here (be sure to add them to setParams below too)
         transformer: ProxyBase,
-        func_get_path: Callable[[str, str, Optional[str]], str],
-        func_get_response_path: Callable[[str, str, Optional[str]], str],
+        func_get_path: Callable[[Optional[str], str, Optional[str]], str],
+        func_get_response_path: Callable[[Optional[str], str, Optional[str]], str],
         fhir_server_url: str,
         source_entity_name: str,
         fhir_validation_url: Optional[str] = None,
@@ -84,13 +84,13 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         self.transformer: Param[ProxyBase] = Param(self, "transformer", "")
         self._setDefault(transformer=transformer)
 
-        self.func_get_path: Param[Callable[[str, str, Optional[str]], str]] = Param(
-            self, "func_get_path", ""
-        )
+        self.func_get_path: Param[
+            Callable[[Optional[str], str, Optional[str]], str]
+        ] = Param(self, "func_get_path", "")
         self._setDefault(func_get_path=func_get_path)
 
         self.func_get_response_path: Param[
-            Callable[[str, str, Optional[str]], str]
+            Callable[[Optional[str], str, Optional[str]], str]
         ] = Param(self, "func_get_response_path", "")
         self._setDefault(func_get_response_path=func_get_response_path)
 
@@ -138,9 +138,11 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
 
     def _transform(self, df: DataFrame) -> DataFrame:
         transformer: ProxyBase = self.getTransformer()
-        func_get_path: Callable[[str, str, Optional[str]], str] = self.getFuncGetPath()
+        func_get_path: Callable[
+            [Optional[str], str, Optional[str]], str
+        ] = self.getFuncGetPath()
         func_get_response_path: Callable[
-            [str, str, Optional[str]], str
+            [Optional[str], str, Optional[str]], str
         ] = self.getFuncGetResponsePath()
         fhir_server_url: str = self.getFhirServerUrl()
         fhir_validation_url: Optional[str] = self.getFhirValidationServerUrl()
@@ -244,11 +246,13 @@ class AutoMapperToFhirTransformer(FrameworkTransformer):
         return self.getOrDefault(self.transformer)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getFuncGetPath(self) -> Callable[[str, str, Optional[str]], str]:
+    def getFuncGetPath(self) -> Callable[[Optional[str], str, Optional[str]], str]:
         return self.getOrDefault(self.func_get_path)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getFuncGetResponsePath(self) -> Callable[[str, str, Optional[str]], str]:
+    def getFuncGetResponsePath(
+        self,
+    ) -> Callable[[Optional[str], str, Optional[str]], str]:
         return self.getOrDefault(self.func_get_response_path)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
