@@ -13,12 +13,16 @@ def get_fhir_client(
     auth_login_token: Optional[str] = None,
     auth_access_token: Optional[str] = None,
     auth_scopes: Optional[List[str]] = None,
+    log_level: Optional[str] = None,
 ) -> FhirClient:
     assert server_url
 
     fhir_client: FhirClient = FhirClient()
     fhir_client = fhir_client.url(server_url)
 
+    if log_level:
+        fhir_client = fhir_client.log_level(log_level)
+
     if auth_server_url:
         fhir_client = fhir_client.auth_server_url(auth_server_url)
     if auth_client_id and auth_client_secret:
@@ -29,6 +33,7 @@ def get_fhir_client(
         fhir_client = fhir_client.set_access_token(auth_access_token)
     if auth_scopes:
         fhir_client = fhir_client.auth_scopes(auth_scopes)
+
     if logger:
         # noinspection PyTypeChecker
         fhir_client = fhir_client.logger(logger)  # type: ignore
